@@ -1,9 +1,9 @@
 package Text::Table::Span;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-14'; # DATE
+our $DATE = '2021-02-15'; # DATE
 our $DIST = 'Text-Table-Span'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -449,7 +449,7 @@ Text::Table::Span - Text::Table::Tiny + support for column/row spans
 
 =head1 VERSION
 
-This document describes version 0.001 of Text::Table::Span (from Perl distribution Text-Table-Span), released on 2021-02-14.
+This document describes version 0.002 of Text::Table::Span (from Perl distribution Text-Table-Span), released on 2021-02-15.
 
 =head1 SYNOPSIS
 
@@ -561,7 +561,7 @@ Or, you can also use the C<cell_attrs> option:
      header_row => 1,
      #border_style => 'ASCII::SingleLineDoubleAfterHeader', # module in BorderStyle::* namespace, without the prefix. default is ASCII::SingleLineDoubleAfterHeader
      cell_attrs => [
-         # rownum (0-based int), colnum (0-based int), styles (hashref)
+         # rownum (0-based int), colnum (0-based int), attributes (hashref)
          [1, 2, {rowspan=>3}],
          [1, 4, {rowspan=>2, colspan=>2}],
          [1, 5, {rowspan=>2, colspan=>2}],
@@ -591,6 +591,32 @@ will output something like:
  |      |                              |                     |                              | The Dick Van Dyke Show (CBS) | I Spy (CBS)      | The Dick Van Dyke Show (CBS) | The Big Valley (CBS) |
  `------+------------------------------+---------------------+------------------------------+------------------------------+------------------+------------------------------+----------------------'
 
+If you set the C<border_style> argument to C<"UTF8::SingleLineBoldHeader">:
+
+ print generate_table(
+     rows => $rows,
+     border_style => "UTF8::SingleLineBoldHeader",
+     ...
+ );
+
+then the output will be something like this:
+
+ ┏━━━━━━┳━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━━┓
+ ┃ Year ┃ Comedy                       ┃ Drama               ┃ Variety                      ┃ Lead Comedy Actor            ┃ Lead Drama Actor ┃ Lead Comedy Actress          ┃ Lead Drama Actress   ┃
+ ┡━━━━━━╇━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┻━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┻━━━━━━━━━━━━━━━━━━━━━━┩
+ │ 1962 │ The Bob Newhart Show (NBC)   │ The Defenders (CBS) │ The Garry Moore Show (CBS)   │ E. G. Marshall                                  │ Shirley Booth                                       │
+ ├──────┼──────────────────────────────┤                     ├──────────────────────────────┤ The Defenders (CBS)                             │ Hazel (NBC)                                         │
+ │ 1963 │ The Dick Van Dyke Show (CBS) │                     │ The Andy Williams Show (NBC) │                                                 │                                                     │
+ ├──────┤                              │                     ├──────────────────────────────┼─────────────────────────────────────────────────┼─────────────────────────────────────────────────────┤
+ │ 1964 │                              │                     │ The Danny Kaye Show (CBS)    │ Dick Van Dyke                                   │ Mary Tyler Moore                                    │
+ │      │                              │                     │                              │ The Dick Van Dyke Show (CBS)                    │ The Dick Van Dyke Show (CBS)                        │
+ ├──────┼──────────────────────────────┴─────────────────────┴──────────────────────────────┼─────────────────────────────────────────────────┴─────────────────────────────────────────────────────┤
+ │ 1965 │ four winners                                                                      │ five winners                                                                                          │
+ ├──────┼──────────────────────────────┬─────────────────────┬──────────────────────────────┼──────────────────────────────┬──────────────────┬──────────────────────────────┬──────────────────────┤
+ │ 1966 │ The Dick Van Dyke Show (CBS) │ The Fugitive (ABC)  │ The Andy Williams Show (NBC) │ Dick Van Dyke                │ Bill Cosby       │ Mary Tyler Moore             │ Barbara Stanwyck     │
+ │      │                              │                     │                              │ The Dick Van Dyke Show (CBS) │ I Spy (CBS)      │ The Dick Van Dyke Show (CBS) │ The Big Valley (CBS) │
+ └──────┴──────────────────────────────┴─────────────────────┴──────────────────────────────┴──────────────────────────────┴──────────────────┴──────────────────────────────┴──────────────────────┘
+
 =head1 DESCRIPTION
 
 This module is like L<Text::Table::Tiny> (0.04) with added support for
